@@ -1,18 +1,14 @@
+use crate::{DdoResolver, Error};
 pub use did_key::*;
-use crate::{
-    DdoResolver,
-    Error,
-};
 
 /// Unit struct which have implementations of `DdoParser` and `DdoResolver`
 ///     traits for `did:key` document resolver.
 ///
-pub struct DidKeyResolver{}
+pub struct DidKeyResolver {}
 
 impl DdoResolver for DidKeyResolver {
     fn resolve(&self, did_url: &str) -> Result<Document, Error> {
-        let key = did_key::resolve(did_url)
-            .map_err(|e| Error::DidKeyError(format!("{:?}", e)))?;
+        let key = did_key::resolve(did_url).map_err(|e| Error::DidKeyError(format!("{:?}", e)))?;
         Ok(key.get_did_document(did_key::CONFIG_LD_PUBLIC))
     }
 }
@@ -20,10 +16,7 @@ impl DdoResolver for DidKeyResolver {
 #[cfg(test)]
 mod did_key_tests {
     use super::*;
-    use crate::{
-        resolve_any,
-        DdoParser
-    };
+    use crate::{resolve_any, DdoParser};
 
     #[test]
     fn did_key_resolve_raw_test() {
@@ -34,7 +27,8 @@ mod did_key_tests {
 
     #[test]
     fn did_key_resolve_trait_test() {
-        let r = DidKeyResolver{}.resolve("did:key:z6MkiTBz1ymuepAQ4HEHYSF1H8quG5GLVVQR3djdX3mDooWp");
+        let r =
+            DidKeyResolver {}.resolve("did:key:z6MkiTBz1ymuepAQ4HEHYSF1H8quG5GLVVQR3djdX3mDooWp");
         assert!(r.is_ok());
     }
 
@@ -52,4 +46,3 @@ mod did_key_tests {
         assert!(k.is_some());
     }
 }
-
